;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

;old-cus-dep-hash: #s(hash-table test equal size 41 data ("/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-eif-ft.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-smt.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-compl.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-python-ft.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-clos.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/hmouse-br.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/objc-brows.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-c-ft.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-c++-ft.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-tree.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/info-brows.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-python.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/auto-autoloads.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-site.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/eif-browse.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-java.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/java-brows.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-vers.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/clos-brows.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br.el" ((br-keep-viewed-classes . "br") (br-invert-ancestors . "br") (br-inhibit-version . "br") (br-protocols-with-classes-flag . "br") (br-inherited-features-flag . "br") (oo-browser . "br")) "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-ftr.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/hasht.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-env.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-objc-ft.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-clos-ft.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-info.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-objc.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-menu.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/c++-browse.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-init.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-eif.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/eif-ise-er.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-java-ft.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-name.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/eif-calls.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/pyth-brows.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-lib.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-c++.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/_pkg.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/br-start.el" nil "/home/nk/pkg-build/test/xemacs-packages/oo-browser/smt-browse.el" nil))
(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'oo-browser '("br"))
(custom-add-loads 'tools '("br"))

;;; custom-load.el ends here
